EventDispatcher class

Other classes can inherit from this class in order to provide an event based API. Useful for controls development.

@author {@link https://github.com/Mugen87|Mugen87}

Constructors

EventDispatcher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, Function listener) → void
Adds an event listener for the given event type.
dispatchEvent(dynamic event) → void
Dispatches an event to all respective event listeners.
hasEventListener(String type, Function listener) bool
Returns true if the given event listener is set for the given event type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, Function listener) → void
Removes the given event listener for the given event type.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited