MeshGeometry class

Class for representing a polygon mesh. The faces consist of triangles.

@author {@link https://github.com/Mugen87|Mugen87}

Constructors

MeshGeometry([List<double>? vertices, List<int>? indices])
Constructs a mesh geometry.

Properties

aabb ↔ AABB
getter/setter pair
backfaceCulling ↔ bool
getter/setter pair
boundingSphere ↔ BoundingSphere
getter/setter pair
closestIntersectionPoint → Vector3
final
closestTriangle → Map<String, Vector3>
final
hashCode → int
The hash code for this object.
no setterinherited
indices ↔ List<int>?
getter/setter pair
inverseMatrix → Matrix4
final
plane → Plane
final
rayLocal → Ray
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triangle → Map<String, Vector3>
final
vertices ↔ List<double>
latefinal

Methods

computeBoundingVolume() → MeshGeometry
Computes the internal bounding volumes of this mesh geometry.
fromJSON(Map<String, dynamic> json) → MeshGeometry
Restores this instance from the given JSON object.
intersectRay(Ray ray, Matrix4 worldMatrix, bool closest, Vector3 intersectionPoint, [Vector3? normal]) → Vector3?
Performs a ray intersection test with the geometry of the obstacle and stores the intersection point in the given result vector. If no intersection is detected, null is returned.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
Transforms this instance into a JSON object.
toString() → String
A string representation of this object.
inherited
toTriangleSoup() → MeshGeometry
Returns a geometry without containing indices. If the geometry is already non-indexed, the method performs no changes.

Operators

operator ==(Object other) → bool
The equality operator.
inherited