computeDegreeOfMembership method
Computes the degree of membership for the given value. Notice that this method does not set {@link FuzzySet#degreeOfMembership} since other classes use it in order to calculate intermediate degree of membership values. This method be implemented by all concrete fuzzy set classes.
Implementation
double computeDegreeOfMembership(double value) {return 0;}