FuzzyTerm class abstract

Base class for representing a term in a {@link FuzzyRule}.

@author {@link https://github.com/Mugen87|Mugen87}

Implementers

Constructors

FuzzyTerm()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String?
Unique ID, primarily used in context of serialization/deserialization.
no setter

Methods

clearDegreeOfMembership() → FuzzyTerm
Clears the degree of membership value.
fromJSON(Map<String, dynamic> json) → FuzzyTerm
Restores this instance from the given JSON object.
getDegreeOfMembership() → double
Returns the degree of membership.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
Transforms this instance into a JSON object.
toString() → String
A string representation of this object.
inherited
updateDegreeOfMembership(double value) → FuzzyTerm
Updates the degree of membership by the given value. This method is used when the term is part of a fuzzy rule's consequent.

Operators

operator ==(Object other) → bool
The equality operator.
inherited