FuzzyAND class

Class for representing an AND operator. Can be used to construct fuzzy rules.

@author {@link https://github.com/Mugen87|Mugen87}

Inheritance

Constructors

FuzzyAND([List<FuzzyTerm>? terms])
Constructs a new fuzzy AND operator with the given values. The constructor accepts and arbitrary amount of fuzzy terms.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms ↔ List<FuzzyTerm>
getter/setter pairinherited
uuid → String?
Unique ID, primarily used in context of serialization/deserialization.
no setterinherited

Methods

clearDegreeOfMembership() → FuzzyCompositeTerm
Clears the degree of membership value.
inherited
fromJSON(Map<String, dynamic> json) → FuzzyTerm
Restores this instance from the given JSON object.
inherited
getDegreeOfMembership() → double
Returns the degree of membership. The AND operator returns the minimum degree of membership of the sets it is operating on.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
Transforms this instance into a JSON object.
inherited
toString() → String
A string representation of this object.
inherited
updateDegreeOfMembership(double value) → FuzzyCompositeTerm
Updates the degree of membership by the given value. This method is used when the term is part of a fuzzy rule's consequent.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited