inactive property
bool
get
inactive
Returns true if the status of this goal is INACTIVE.
Implementation
bool get inactive => status == GoalStatus.inactive;
Returns true if the status of this goal is INACTIVE.
bool get inactive => status == GoalStatus.inactive;