Plane class

Class representing a plane in 3D space. The plane is specified in Hessian normal form.

@author {@link https://github.com/Mugen87|Mugen87}

Constructors

Plane([Vector3? normal, double constant = 0])
Constructs a new plane with the given values.

Properties

constant ↔ double
getter/setter pair
d → Vector3
final
hashCode → int
The hash code for this object.
no setterinherited
normal ↔ Vector3
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v1 → Vector3
final
v2 → Vector3
final

Methods

clone() → Plane
Creates a new plane and copies all values from this plane.
copy(Plane plane) → Plane
Copies all values from the given plane to this plane.
distanceToPoint(Vector3 point) → double
Computes the signed distance from the given 3D vector to this plane. The sign of the distance indicates the half-space in which the points lies. Zero means the point lies on the plane.
equals(Plane plane) → bool
Returns true if the given plane is deep equal with this plane.
fromCoplanarPoints(Vector3 a, Vector3 b, Vector3 c) → Plane
Sets the values of the plane from three given coplanar points.
fromNormalAndCoplanarPoint(Vector3 normal, Vector3 point) → Plane
Sets the values of the plane from the given normal vector and a coplanar point.
intersectPlane(Plane plane, Vector3 result) → Vector3?
Performs a plane/plane intersection test and stores the intersection point to the given 3D vector. If no intersection is detected, null is returned.
intersectsPlane(Plane plane) → bool
Returns true if the given plane intersects this plane.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectPoint(Vector3 point, Vector3 result) → Vector3
Projects the given point onto the plane. The result is written to the given vector.
set(Vector3 normal, double constant) → Plane
Sets the given values to this plane.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited