copy method
Copies all values from the given quaternion to this quaternion.
Implementation
Quaternion copy(Quaternion q ) {
x = q.x;
y = q.y;
z = q.z;
w = q.w;
return this;
}
Copies all values from the given quaternion to this quaternion.
Quaternion copy(Quaternion q ) {
x = q.x;
y = q.y;
z = q.z;
w = q.w;
return this;
}