SAT class

Implementation of the separating axis theorem (SAT). Used to detect intersections between convex polyhedra. The code is based on the presentation {@link http://twvideo01.ubm-us.net/o1/vault/gdc2013/slides/822403Gregorius_Dirk_TheSeparatingAxisTest.pdf The Separating Axis Test between convex polyhedra} by Dirk Gregorius (Valve Software) from GDC 2013.

@author {@link https://github.com/Mugen87|Mugen87}

Constructors

SAT()

Properties

c → Vector3
final
d → Vector3
final
directionA → Vector3
final
directionB → Vector3
final
hashCode → int
The hash code for this object.
no setterinherited
normal → Vector3
final
oppositeNormal → Vector3
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v → Vector3
final

Methods

intersects(Polyhedron polyhedronA, Polyhedron polyhedronB) → bool
Returns true if the given convex polyhedra intersect. A polyhedron is just an array of {@link Polygon} objects.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited