NavNode class

Class for representing navigation nodes.

@author {@link https://github.com/Mugen87|Mugen87}

Inheritance

Constructors

Constructs a new navigation node.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pairinherited
position ↔ Vector3
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userData ↔ Map<String, dynamic>
latefinal

Methods

fromJSON(Map<String, dynamic> json) → Node
Restores this instance from the given JSON object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
Transforms this instance into a JSON object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited