navigation/navmesh/nav_mesh library

Classes

Implementation of a navigation mesh. A navigation mesh is a network of convex polygons which define the walkable areas of a game environment. A convex polygon allows unobstructed travel from any point in the polygon to any other. This is useful because it enables the navigation mesh to be represented using a graph where each node represents a convex polygon and their respective edges represent the neighborly relations to other polygons. More compact navigation graphs lead to faster graph search execution.