Cell class

Class for representing a single partition in context of cell-space partitioning.

@author {@link https://github.com/Mugen87|Mugen87}

Constructors

Cell([AABB? aabb])
Constructs a new cell with the given values.

Properties

aabb ↔ AABB
getter/setter pair
entries → List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(dynamic entry) → Cell
Adds an entry to this cell.
empty() → bool
Returns true if this cell is empty.
fromJSON(Map<String, dynamic> json) → Cell
Restores this instance from the given JSON object.
intersects(AABB aabb) → bool
Returns true if the given AABB intersects the internal bounding volume of this cell.
makeEmpty() → Cell
Removes all entries from this cell.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(dynamic entry) → Cell
Removes an entry from this cell.
resolveReferences(Map<String, GameEntity> entities) → Cell
Restores UUIDs with references to GameEntity objects.
toJSON() → Map<String, dynamic>
Transforms this instance into a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited