Path class

Class for representing a walkable path.

@author {@link https://github.com/Mugen87|Mugen87}

Constructors

Path()

Properties

hashCode → int
The hash code for this object.
no setterinherited
loop ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
waypoints → List<Vector3>
final

Methods

add(Vector3 waypoint) → Path
Adds the given waypoint to this path.
advance() → Path
Makes the next waypoint of this path active. If the path is looped and returns true, the path starts from the beginning.
clear() → Path
Clears the internal state of this path.
current() → Vector3
Returns the current active waypoint of this path.
finished() → bool
Returns true if this path is not looped and the last waypoint is active.
fromJSON(Map<String, dynamic> json) → Path
Restores this instance from the given JSON object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
Transforms this instance into a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited