calculate method
Calculates the steering forces for all active steering behaviors and combines it into a single result force. This method is called in
Implementation
Vector3 calculate(double delta, Vector3 result ) {
_calculateByOrder( delta );
return result.copy( _steeringForce );
}