HeuristicPolicyEuclidSquared class
Class for representing a heuristic for graph search algorithms based on the squared euclidean distance. The heuristic assumes that the node have a position property of type {@link Vector3}.
@author {@link https://github.com/Mugen87|Mugen87}
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited