Smoother class
This class can be used to smooth the result of a vector calculation. One use case is the smoothing of the velocity vector of game entities in order to avoid a shaky movements due to conflicting forces.
Properties
Methods
-
calculate(
Vector3 value, Vector3 average) → Vector3 - Calculates for the given value a smooth average.
-
fromJSON(
Map< String, dynamic> json) → Smoother - Restores this instance from the given JSON object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → Map< String, dynamic> - Transforms this instance into a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited